@@ -62,14 +62,14 @@ mod tests {
     fn it_can_be_created_from_a_str() {
         let comment = Comment::from("# Example Comment");
 
-        assert_eq!(String::from(comment), String::from("# Example Comment"))
+        assert_eq!(String::from(comment), String::from("# Example Comment"));
     }
 
     #[test]
     fn it_can_be_created_from_a_string() {
         let comment = Comment::from(String::from("# Example Comment"));
 
-        assert_eq!(String::from(comment), String::from("# Example Comment"))
+        assert_eq!(String::from(comment), String::from("# Example Comment"));
     }
 
     #[test]
@@ -81,6 +81,6 @@ mod tests {
             Example 2"
             )),
             Comment::from("Example 1").append(&Comment::from("Example 2"))
-        )
+        );
     }
 }
