@@ -136,14 +136,14 @@ mod tests {
     fn it_can_tell_me_its_key() {
         let trailer = Trailer::new("Relates-to", "#128");
 
-        assert_eq!(trailer.get_key(), String::from("Relates-to"))
+        assert_eq!(trailer.get_key(), String::from("Relates-to"));
     }
 
     #[test]
     fn it_can_tell_me_its_value() {
         let trailer = Trailer::new("Relates-to", "#128");
 
-        assert_eq!(trailer.get_value(), String::from("#128"))
+        assert_eq!(trailer.get_value(), String::from("#128"));
     }
 
     #[test]
@@ -151,7 +151,7 @@ mod tests {
         let a = Trailer::new("Relates-to", "#128\n");
         let b = Trailer::new("Relates-to", "#128");
 
-        assert_eq!(a, b)
+        assert_eq!(a, b);
     }
 
     #[test]
@@ -162,14 +162,14 @@ mod tests {
         let mut hasher_b = DefaultHasher::new();
         Trailer::new("Relates-to", "#128").hash(&mut hasher_b);
 
-        assert_eq!(hasher_a.finish(), hasher_b.finish())
+        assert_eq!(hasher_a.finish(), hasher_b.finish());
     }
 
     #[test]
     fn it_can_give_me_itself_as_a_string() {
         let trailer = Trailer::new("Relates-to", "#128");
 
-        assert_eq!(String::from(trailer), String::from("Relates-to: #128"))
+        assert_eq!(String::from(trailer), String::from("Relates-to: #128"));
     }
 
     #[test]
@@ -179,7 +179,7 @@ mod tests {
         assert_eq!(
             String::from(trailer.expect("Could not parse from string")),
             String::from("Relates-to: #128")
-        )
+        );
     }
 
     #[test]
@@ -189,7 +189,7 @@ mod tests {
         assert_eq!(
             String::from(trailer.expect("Could not parse from string")),
             String::from("Relates-to:      #128\n")
-        )
+        );
     }
 
     #[test]
@@ -197,6 +197,6 @@ mod tests {
         let trailer = Trailer::new("Relates-to", "#128");
         let body: Fragment = Fragment::from(trailer);
 
-        assert_eq!(body, Fragment::Body(Body::from("Relates-to: #128")))
+        assert_eq!(body, Fragment::Body(Body::from("Relates-to: #128")));
     }
 }
